@@ -5,18 +5,42 @@ from threading import Thread
 from eqsmart.components.protocol import *
 
 
+def not_c_key(p_dict, p_key):
+    """
+    判断不包含元素
+    :param p_dict: 字典
+    :param p_key: key
+    :return: p_dict 不包含 p_key, 返回 True
+    """
+    try:
+        if p_dict.__contains__(p_key) is True and p_dict[p_key] is not None and p_dict[p_key] != '':
+            return False
+    except Exception as e:
+        print('[eqsmart]', 'conf check', str(e))
+    return True
+
+
 class Provider:
     def __init__(self, provider_conf, server_info, server_list):
+        self.provider_conf = {}
         self.server_info = server_info
         self.server_list = server_list
-        self.provider_conf = provider_conf
+        self.provider_conf['HOST'] = '127.0.0.1' if not_c_key(provider_conf, 'HOST') else provider_conf['HOST']
+        self.provider_conf['PORT'] = 7901 if not_c_key(provider_conf, 'PORT') else provider_conf['PORT']
+        self.provider_conf['BACKLOG'] = 5 if not_c_key(provider_conf, 'BACKLOG') else provider_conf['BACKLOG']
+        self.provider_conf['BUF_SIZE'] = 1024 if not_c_key(provider_conf, 'BUF_SIZE') else provider_conf['BUF_SIZE']
+        self.provider_conf['IP'] = '127.0.0.1' if not_c_key(provider_conf, 'IP') else provider_conf['IP']
+        self.provider_conf['WEIGHT'] = 1 if not_c_key(provider_conf, 'IP') else provider_conf['WEIGHT']
 
     def __send_data__(self):
         register_data = []
-        weight = self.provider_conf['WEIGHT'] if self.provider_conf.__contains__('WEIGHT') else 1
         send_data = {
             'type': 'provider register',
-            'remote': {'ip': self.provider_conf['HOST'], 'port': self.provider_conf['PORT'], 'weight': weight},
+            'remote': {
+                'ip': self.provider_conf['IP'],
+                'port': self.provider_conf['PORT'],
+                'weight': self.provider_conf['WEIGHT']
+            },
             'service_name': '',
             'func': []
         }
@@ -27,7 +51,6 @@ class Provider:
         return register_data
 
     def __func_call__(self, connect):
-        print('监听客户端请求')
         while True:
             '''处理客户端端数据'''
             try:
@@ -79,7 +102,6 @@ class Provider:
             """
             bind() 绑定地址(host,port)到套接字， 在AF_INET下，以元组(host,port)的形式表示地址
             """
-            self.provider_conf['HOST'] = socket.gethostbyname(socket.gethostname())
             server.bind((self.provider_conf['HOST'], self.provider_conf['PORT']))
             print('[eqsmart] [Provider Starting] ' + self.provider_conf['HOST'] + ':' + str(self.provider_conf['PORT']))
         except socket.error as e:
@@ -87,7 +109,7 @@ class Provider:
             sys.exit()
         print("[eqsmart] Provider bind complete")
 
-        # TODO 启动一个线程，将自身注册到注册中心
+        ''' 启动一个线程，将自身注册到注册中心 '''
         send_data = self.__send_data__()
         for i in send_data:
             Thread(target=register, args=(i,)).start()
